# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List
from typing_extensions import Annotated
from organizze_api.models.transaction import Transaction
from typing import Optional, Set
from typing_extensions import Self

class CreditCardInvoiceFull(BaseModel):
    """
    CreditCardInvoiceFull
    """ # noqa: E501
    id: Annotated[int, Field(le=2147483647, strict=True, ge=1)]
    var_date: date = Field(alias="date")
    starting_date: date
    closing_date: date
    amount_cents: StrictInt
    payment_amount_cents: StrictInt
    balance_cents: StrictInt
    previous_balance_cents: StrictInt
    credit_card_id: Annotated[int, Field(le=2147483647, strict=True, ge=1)]
    transactions: Annotated[List[Transaction], Field(min_length=0)]
    payments: Annotated[List[Transaction], Field(min_length=0)]
    __properties: ClassVar[List[str]] = ["id", "date", "starting_date", "closing_date", "amount_cents", "payment_amount_cents", "balance_cents", "previous_balance_cents", "credit_card_id", "transactions", "payments"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreditCardInvoiceFull from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in transactions (list)
        _items = []
        if self.transactions:
            for _item_transactions in self.transactions:
                if _item_transactions:
                    _items.append(_item_transactions.to_dict())
            _dict['transactions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in payments (list)
        _items = []
        if self.payments:
            for _item_payments in self.payments:
                if _item_payments:
                    _items.append(_item_payments.to_dict())
            _dict['payments'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreditCardInvoiceFull from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "date": obj.get("date"),
            "starting_date": obj.get("starting_date"),
            "closing_date": obj.get("closing_date"),
            "amount_cents": obj.get("amount_cents"),
            "payment_amount_cents": obj.get("payment_amount_cents"),
            "balance_cents": obj.get("balance_cents"),
            "previous_balance_cents": obj.get("previous_balance_cents"),
            "credit_card_id": obj.get("credit_card_id"),
            "transactions": [Transaction.from_dict(_item) for _item in obj["transactions"]] if obj.get("transactions") is not None else None,
            "payments": [Transaction.from_dict(_item) for _item in obj["payments"]] if obj.get("payments") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.update_transaction_request import UpdateTransactionRequest

class TestUpdateTransactionRequest(unittest.TestCase):
    """UpdateTransactionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTransactionRequest:
        """Test UpdateTransactionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTransactionRequest`
        """
        model = UpdateTransactionRequest()
        if include_optional:
            return UpdateTransactionRequest(
                id = 1,
                description = '',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                paid = True,
                amount_cents = -2147483647,
                total_installments = 1,
                installment = 1,
                recurring = True,
                account_id = 1,
                account_type = 'Account',
                category_id = 1,
                notes = '',
                attachments_count = 0,
                credit_card_id = 1,
                credit_card_invoice_id = 1,
                paid_credit_card_id = 1,
                paid_credit_card_invoice_id = 1,
                oposite_transaction_id = 1,
                oposite_account_id = 1,
                created_at = '-8072i_0408 20012345678910111213141516171819',
                updated_at = '-8072i_0408 20012345678910111213141516171819',
                tags = [
                    ''
                    ],
                attachments = [
                    ''
                    ],
                update_future = True,
                update_all = True
            )
        else:
            return UpdateTransactionRequest(
        )
        """

    def testUpdateTransactionRequest(self):
        """Test UpdateTransactionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "BankAccountsApi",
    "BudgetsApi",
    "CategoriesApi",
    "CreditCardsApi",
    "TransactionsApi",
    "UsersApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BankAccount",
    "BankAccountInput",
    "Budget",
    "Category",
    "CategoryInput",
    "CreateTransactionRequest",
    "CreditCard",
    "CreditCardInput",
    "CreditCardInvoice",
    "CreditCardInvoiceFull",
    "DeleteTransactionRequest",
    "FailedAuthentication",
    "InstallmentTransaction",
    "InstallmentTransactionAllOfInstallmentsAttributes",
    "NotFound",
    "RecurringTransaction",
    "RecurringTransactionAllOfRecurrenceAttributes",
    "Tag",
    "Transaction",
    "TransactionInput",
    "TransactionTagsInner",
    "UpdateTransactionRequest",
    "User",
    "ValidationError",
]

# import apis into sdk package
from organizze_api.api.bank_accounts_api import BankAccountsApi as BankAccountsApi
from organizze_api.api.budgets_api import BudgetsApi as BudgetsApi
from organizze_api.api.categories_api import CategoriesApi as CategoriesApi
from organizze_api.api.credit_cards_api import CreditCardsApi as CreditCardsApi
from organizze_api.api.transactions_api import TransactionsApi as TransactionsApi
from organizze_api.api.users_api import UsersApi as UsersApi

# import ApiClient
from organizze_api.api_response import ApiResponse as ApiResponse
from organizze_api.api_client import ApiClient as ApiClient
from organizze_api.configuration import Configuration as Configuration
from organizze_api.exceptions import OpenApiException as OpenApiException
from organizze_api.exceptions import ApiTypeError as ApiTypeError
from organizze_api.exceptions import ApiValueError as ApiValueError
from organizze_api.exceptions import ApiKeyError as ApiKeyError
from organizze_api.exceptions import ApiAttributeError as ApiAttributeError
from organizze_api.exceptions import ApiException as ApiException

# import models into sdk package
from organizze_api.models.bank_account import BankAccount as BankAccount
from organizze_api.models.bank_account_input import BankAccountInput as BankAccountInput
from organizze_api.models.budget import Budget as Budget
from organizze_api.models.category import Category as Category
from organizze_api.models.category_input import CategoryInput as CategoryInput
from organizze_api.models.create_transaction_request import CreateTransactionRequest as CreateTransactionRequest
from organizze_api.models.credit_card import CreditCard as CreditCard
from organizze_api.models.credit_card_input import CreditCardInput as CreditCardInput
from organizze_api.models.credit_card_invoice import CreditCardInvoice as CreditCardInvoice
from organizze_api.models.credit_card_invoice_full import CreditCardInvoiceFull as CreditCardInvoiceFull
from organizze_api.models.delete_transaction_request import DeleteTransactionRequest as DeleteTransactionRequest
from organizze_api.models.failed_authentication import FailedAuthentication as FailedAuthentication
from organizze_api.models.installment_transaction import InstallmentTransaction as InstallmentTransaction
from organizze_api.models.installment_transaction_all_of_installments_attributes import InstallmentTransactionAllOfInstallmentsAttributes as InstallmentTransactionAllOfInstallmentsAttributes
from organizze_api.models.not_found import NotFound as NotFound
from organizze_api.models.recurring_transaction import RecurringTransaction as RecurringTransaction
from organizze_api.models.recurring_transaction_all_of_recurrence_attributes import RecurringTransactionAllOfRecurrenceAttributes as RecurringTransactionAllOfRecurrenceAttributes
from organizze_api.models.tag import Tag as Tag
from organizze_api.models.transaction import Transaction as Transaction
from organizze_api.models.transaction_input import TransactionInput as TransactionInput
from organizze_api.models.transaction_tags_inner import TransactionTagsInner as TransactionTagsInner
from organizze_api.models.update_transaction_request import UpdateTransactionRequest as UpdateTransactionRequest
from organizze_api.models.user import User as User
from organizze_api.models.validation_error import ValidationError as ValidationError




# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.credit_cards_api import CreditCardsApi


class TestCreditCardsApi(unittest.TestCase):
    """CreditCardsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CreditCardsApi()

    def tearDown(self) -> None:
        pass

    def test_create_credit_card(self) -> None:
        """Test case for create_credit_card

        Create Credit Card
        """
        pass

    def test_delete_credit_card(self) -> None:
        """Test case for delete_credit_card

        Delete Credit Card
        """
        pass

    def test_list_credit_card_invoice_payments(self) -> None:
        """Test case for list_credit_card_invoice_payments

        List Credit Card Invoice Payments
        """
        pass

    def test_list_credit_card_invoices(self) -> None:
        """Test case for list_credit_card_invoices

        List Credit Card Invoices
        """
        pass

    def test_list_credit_cards(self) -> None:
        """Test case for list_credit_cards

        List Credit Cards
        """
        pass

    def test_read_credit_card(self) -> None:
        """Test case for read_credit_card

        Read Credit Card
        """
        pass

    def test_read_credit_card_invoice(self) -> None:
        """Test case for read_credit_card_invoice

        Read Credit Card Invoice
        """
        pass

    def test_update_credit_card(self) -> None:
        """Test case for update_credit_card

        Update Credit Card
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.bank_accounts_api import BankAccountsApi


class TestBankAccountsApi(unittest.TestCase):
    """BankAccountsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BankAccountsApi()

    def tearDown(self) -> None:
        pass

    def test_create_bank_account(self) -> None:
        """Test case for create_bank_account

        Create Bank Account
        """
        pass

    def test_delete_bank_account(self) -> None:
        """Test case for delete_bank_account

        Delete Bank Account
        """
        pass

    def test_list_bank_accounts(self) -> None:
        """Test case for list_bank_accounts

        List Bank Accounts
        """
        pass

    def test_read_bank_account(self) -> None:
        """Test case for read_bank_account

        Read Account
        """
        pass

    def test_update_bank_account(self) -> None:
        """Test case for update_bank_account

        Update Bank Account
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
Organizze API

Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from setuptools import setup, find_packages  # noqa: H301
from pathlib import Path

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools


# Read version from pyproject.toml (compatible with Python 3.9+)
def get_version():
    """Read version from pyproject.toml without requiring tomllib"""
    pyproject_path = Path(__file__).parent / "pyproject.toml"
    with open(pyproject_path, "r") as f:
        for line in f:
            if line.startswith("version ="):
                return line.split("=")[1].strip().strip('"').strip("'")
    return "0.0.0"


NAME = "organizze_api"
VERSION = get_version()
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="SDK to interface with the Organizze REST API",
    author="Rhuan Barreto",
    author_email="rhuan@barreto.work",
    url="https://pypi.org/project/organizze_api/",
    keywords=["OpenAPI", "OpenAPI-Generator", "Organizze API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache-2.0",
    long_description_content_type="text/markdown",
    long_description="""\
    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)
    """,  # noqa: E501
    package_data={"organizze_api": ["py.typed"]},
)



# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.api.categories_api import CategoriesApi


class TestCategoriesApi(unittest.TestCase):
    """CategoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CategoriesApi()

    def tearDown(self) -> None:
        pass

    def test_create_category(self) -> None:
        """Test case for create_category

        Create Category
        """
        pass

    def test_delete_category(self) -> None:
        """Test case for delete_category

        Delete Category
        """
        pass

    def test_list_categories(self) -> None:
        """Test case for list_categories

        List Categories
        """
        pass

    def test_read_category(self) -> None:
        """Test case for read_category

        Read Category
        """
        pass

    def test_update_category(self) -> None:
        """Test case for update_category

        Update Category
        """
        pass


if __name__ == '__main__':
    unittest.main()
